=======
Credits
=======

Development Lead
----------------

* Stefan Ecklebe <stefan.ecklebe@tu-dresden.de>
* Marcus Riesmeier <marcus.riesmeier@umit.at>

Contributors
------------

* Jens Wurm <jens.wurm@umit.at>
* Florian Alber <albflo@hotmail.de>
